baseObjects.IndexStore

|  | ## Cheshire3 Object Model: Class IndexStore

Module baseObjects :: Class IndexStore

## Class IndexStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           IndexStore

Known Subclasses:
  indexStore.BdbIndexStore, postgres.PostgresIndexStore

A persistent storage mechanism for extracted terms.
Instance Methods

begin_indexing(self, session, req) Perform tasks as required before indexing begins, for example setting batch files.
clean_index(self, session, index) Remove all the terms from an index, but keep the specification.
commit_indexing(self, session, req) Commit the data to disk from the indexing process.
contains_index(self, session, index) Does the IndexStore currently store the given Index.
create_index(self, session, index) Create an index in the store.
delete_index(self, session, index) Completely delete an index from the store.
delete_terms(self, session, index, terms, record=None) Delete the given terms from an index, optionally only for a particular record.
fetch_indexList(self, session) Fetch a list of all indexes stored in this IndexStore.
fetch_indexStats(self, session, index) Fetch statistics (such as size) about the given Index.
fetch_sortValue(self, session, index, record) Fetch a stored data value for the given record.
fetch_term(self, session, index, term, summary=0, reverse=0) Fetch a single term.
fetch_termList(self, session, index, term, numReq=0, relation="", end="", summary=0, reverse=0) Fetch a list of terms for an index.
store_terms(self, session, index, terms, record) Store terms in the index for a given record.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### begin_indexing(self, session, req) | source code
Perform tasks as required before indexing begins, for example setting batch files.

### clean_index(self, session, index) | source code
Remove all the terms from an index, but keep the specification.

### commit_indexing(self, session, req) | source code
Commit the data to disk from the indexing process.

### contains_index(self, session, index) | source code
Does the IndexStore currently store the given Index.

### create_index(self, session, index) | source code
Create an index in the store.

### delete_index(self, session, index) | source code
Completely delete an index from the store.

### delete_terms(self, session, index, terms, record=None) | source code
Delete the given terms from an index, optionally only for a particular record.

### fetch_indexList(self, session) | source code
Fetch a list of all indexes stored in this IndexStore.

### fetch_indexStats(self, session, index) | source code
Fetch statistics (such as size) about the given Index.

### fetch_sortValue(self, session, index, record) | source code
Fetch a stored data value for the given record.

### fetch_term(self, session, index, term, summary=0, reverse=0) | source code
Fetch a single term.

### fetch_termList(self, session, index, term, numReq=0, relation="", end="", summary=0, reverse=0) | source code
Fetch a list of terms for an index. numReq: How many terms are wanted. relation: Which order to scan through the index. end: A point to end at (eg between A and B) summary: Only return frequency info, not the pointers to matching records. reverse: Use the reversed index if available (eg 'xedni' not 'index').

### store_terms(self, session, index, terms, record) | source code
Store terms in the index for a given record.